!{\src2tex{textfont=tt}}
!!****f* USPP2PAW/initmesh
!! NAME
!! initmesh
!!
!! FUNCTION
!! Initialize the radial mesh (here only logarithmic mesh)
!!
!! COPYRIGHT
!! Copyright (C) 1998-2014 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the GNU General Public License
!! See http://www.gnu.org/copyleft/gpl.txt
!!
!! INPUTS
!!  pawrad
!!    %max_meshsz= Max. size of radial mesh
!!  lstep= Logarithmic step corresponding to radial mesh
!!  rstep= Radial step corresponding to radial mesh
!!
!! OUTPUT
!!  pawrad
!!    %factzero= Factor to compute value of functions at r=0
!!    %lstep= Logarithimic step corresponding to radial mesh
!!    %rad(max_meshsz)= Coordinates of the radial grid
!!    %radfact(max_meshsz)= Factor used to compute radial integrals on generalized grid
!!    %rstep= Radial step corresponding to radial mesh
!!
!! PARENTS
!!      uspp2paw
!!
!! SOURCE

 subroutine initmesh(pawrad,lstep,rstep)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ---------------------------------------------
 real(dp) :: lstep,rstep
 type(pawrad_type) :: pawrad

!Local variables ---------------------------------------
 integer :: ir,mm,nn
 real(dp) :: h3

!--------------------------------------------------------

 pawrad%lstep=lstep
 pawrad%rstep=rstep
 nn=pawrad%mesh_size

 pawrad%rad(1)=zero;pawrad%radfact(1)=rstep
 do ir=2,nn
  pawrad%rad(ir)    =rstep*(exp(lstep*dble(ir-1))-one)
  pawrad%radfact(ir)=pawrad%rad(ir)+rstep
 end do

 h3=lstep/3.d0;mm=nn-2+mod(nn,2)

 end subroutine
!!***
