!{\src2tex{textfont=tt}}
!!****f* USPP2PAW/rdusps1
!! NAME
!! rdusps1
!! 
!! FUNCTION
!! Read various usefull data (scalars) from USpp code (D. Vanderbilt)
!!
!!
!! COPYRIGHT
!! Copyright (C) 1998-2014 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the GNU General Public License
!! See http://www.gnu.org/copyleft/gpl.txt
!!
!! INPUT
!!  version= version number for USPP2PAW
!!
!! OUTPUT
!!  pshead
!!    %atomic_charge= Total atomic charge
!!    %basis_size= Number of elements for the paw nl basis
!!    %lmn_size= Number of elements for the paw basis
!!    %log_step= Logaritmic step corresponding to radial mesh
!!    %max_meshsz=Maximal mesh size for densities/potentials
!!    %orbitals(basis_size)= Quantum number l for each basis function
!!    %prj_meshsz=Dimension of radial mesh for tProj inherited from uspp
!!    %rad_step= Radial step corresponding to radial mesh
!!    %rc_cor= Pseudization radius for core density
!!    %rc_sph= Default PAW sphere radius
!!    %rc_loc= Pseudization radius for local potential
!!    %sph_meshsz=Dimension of radial mesh for spheres
!!    %title= Title for pseudopotential
!!    %valence_charge= Valence charge
!!    %vbar_meshsz= Dimension of radial mesh for Vbare
!!    %wav_meshsz=Mesh size for partial waves and projectors inherited from uspp
!!  usdata
!!    %exfact= USpp s code number for the exchange-correlation
!!    %nval= Number of valence states
!!  un_log= Unit number for log file (comments)
!!
!! PARENTS
!!      uspp2paw
!!
!! CHILDREN
!!
!! SOURCE

 subroutine rdusps1(pshead,usdata,un_log,version)

 use defs_basis
 use defs_pawps
 
 implicit none

 include "usppcom.inc"

!Arguments ---------------------------------------------
 integer :: un_log
 character*5 :: version
!Theses types are defined in defs_pawps
 type(pshead_type) :: pshead
 type(usdata_type)   :: usdata

!Local variables ---------------------------------------
 integer :: ib

! *************************************************************************

! -- Read TITLE
 write(unit=pshead%title,fmt='(3a)') trim(ADJUSTL(ustitle)), &
&  " - PAW data extracted from US-psp (D.Vanderbilt) - generated by USppPAW v",version

!--Read INTEGERS
 pshead%basis_size=usbassz
 pshead%sph_meshsz=usmshsph
 pshead%vbar_meshsz=usmshvbr
 pshead%prj_meshsz=usmshprj
 pshead%wav_meshsz=usmeshwav
 pshead%max_meshsz=usmeshmax
 usdata%nval=usnval

!-- Read REALS
 pshead%atomic_charge=uszatm
 pshead%valence_charge=uszval
 pshead%core_charge=pshead%atomic_charge-pshead%valence_charge
 usdata%exfact=usexfact
 pshead%rad_step=usradstp
 pshead%log_step=uslogstp
 pshead%rc_sph=usrcsph
 pshead%rc_cor=usrccor
 pshead%rc_loc=usrcloc

!-- Read ORBITAL BASIS
 pshead%orbitals(1:pshead%basis_size)=usorb(1:usbassz)
 pshead%lmn_size=0
 do ib=1,pshead%basis_size
  pshead%lmn_size=pshead%lmn_size+2*pshead%orbitals(ib)+1
 enddo

 un_log=stderr

 end subroutine
!!***
